@@ -7,12 +7,19 @@
 #include "numpy/ndarraytypes.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct {
     int key_len;  /* number of identities used */
     /* Buckets stores: val1, key1[0], key1[1], ..., val2, key2[0], ... */
     PyObject **buckets;
     npy_intp size;  /* current size */
     npy_intp nelem;  /* number of elements */
+#ifdef Py_GIL_DISABLED
+    void *mutex; /* std::shared_mutex, prevents races to fill the cache */
+#endif
 } PyArrayIdentityHash;
 
 
@@ -20,6 +27,11 @@ NPY_NO_EXPORT int
 PyArrayIdentityHash_SetItem(PyArrayIdentityHash *tb,
         PyObject *const *key, PyObject *value, int replace);
 
+#ifdef Py_GIL_DISABLED
+NPY_NO_EXPORT PyObject *
+PyArrayIdentityHash_GetItemWithLock(PyArrayIdentityHash *tb, PyObject *const *key);
+#endif // Py_GIL_DISABLED
+
 NPY_NO_EXPORT PyObject *
 PyArrayIdentityHash_GetItem(PyArrayIdentityHash *tb, PyObject *const *key);
 
@@ -29,4 +41,8 @@ PyArrayIdentityHash_New(int key_len);
 NPY_NO_EXPORT void
 PyArrayIdentityHash_Dealloc(PyArrayIdentityHash *tb);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif  /* NUMPY_CORE_SRC_COMMON_NPY_NPY_HASHTABLE_H_ */
