@@ -8,6 +8,7 @@
 #include "numpy/npy_3kcompat.h"
 #include "npy_pycompat.h"
 #include "alloc.h"
+#include "shape.h"  // For PyArray_Resize_int
 
 #include <string.h>
 #include <stdbool.h>
@@ -61,7 +62,7 @@ create_conv_funcs(
     Py_ssize_t pos = 0;
     int error = 0;
     Py_BEGIN_CRITICAL_SECTION(converters);
-    while (PyDict_Next(converters, &pos, &key, &value)) {
+    while (PyDict_Next(converters, &pos, &key, &value)) { // noqa: borrowed-ref OK
         Py_ssize_t column = PyNumber_AsSsize_t(key, PyExc_IndexError);
         if (column == -1 && PyErr_Occurred()) {
             PyErr_Format(PyExc_TypeError,
@@ -118,7 +119,7 @@ create_conv_funcs(
     if (error) {
         goto error;
     }
-    
+
     return conv_funcs;
 
   error:
@@ -156,7 +157,7 @@ create_conv_funcs(
  *        returned array can differ for strings.
  * @param homogeneous Whether the datatype of the array is not homogeneous,
  *        i.e. not structured.  In this case the number of columns has to be
- *        discovered an the returned array will be 2-dimensional rather than
+ *        discovered and the returned array will be 2-dimensional rather than
  *        1-dimensional.
  *
  * @returns Returns the result as an array object or NULL on error.  The result
@@ -175,10 +176,9 @@ read_rows(stream *s,
     npy_intp row_size = out_descr->elsize;
     PyObject **conv_funcs = NULL;
 
-    bool needs_init = PyDataType_FLAGCHK(out_descr, NPY_NEEDS_INIT);
-
     int ndim = homogeneous ? 2 : 1;
     npy_intp result_shape[2] = {0, 1};
+    PyArray_Dims new_dims = {result_shape, ndim};  /* for resizing */
 
     bool data_array_allocated = data_array == NULL;
     /* Make sure we own `data_array` for the purpose of error handling */
@@ -311,9 +311,6 @@ read_rows(stream *s,
                 if (data_array == NULL) {
                     goto error;
                 }
-                if (needs_init) {
-                    memset(PyArray_BYTES(data_array), 0, PyArray_NBYTES(data_array));
-                }
             }
             else {
                 assert(max_rows >=0);
@@ -354,22 +351,15 @@ read_rows(stream *s,
                         "providing a maximum number of rows to read may help.");
                 goto error;
             }
-
-            char *new_data = PyDataMem_UserRENEW(
-                    PyArray_BYTES(data_array), alloc_size ? alloc_size : 1,
-                    PyArray_HANDLER(data_array));
-            if (new_data == NULL) {
-                PyErr_NoMemory();
+            /*
+             * Resize the array.
+             */
+            result_shape[0] = new_rows;
+            if (PyArray_Resize_int(data_array, &new_dims, 0) < 0) {
                 goto error;
             }
-            /* Replace the arrays data since it may have changed */
-            ((PyArrayObject_fields *)data_array)->data = new_data;
-            ((PyArrayObject_fields *)data_array)->dimensions[0] = new_rows;
-            data_ptr = new_data + row_count * row_size;
+            data_ptr = (char *)PyArray_DATA(data_array) + row_count * row_size;
             data_allocated_rows = new_rows;
-            if (needs_init) {
-                memset(data_ptr, '\0', (new_rows - row_count) * row_size);
-            }
         }
 
         for (Py_ssize_t i = 0; i < actual_num_fields; ++i) {
@@ -474,20 +464,13 @@ read_rows(stream *s,
 
     /*
      * Note that if there is no data, `data_array` may still be NULL and
-     * row_count is 0.  In that case, always realloc just in case.
+     * row_count is 0.  In that case, always resize just in case.
      */
     if (data_array_allocated && data_allocated_rows != row_count) {
-        size_t size = row_count * row_size;
-        char *new_data = PyDataMem_UserRENEW(
-                PyArray_BYTES(data_array), size ? size : 1,
-                PyArray_HANDLER(data_array));
-        if (new_data == NULL) {
-            Py_DECREF(data_array);
-            PyErr_NoMemory();
-            return NULL;
+        result_shape[0] = row_count;
+        if (PyArray_Resize_int(data_array, &new_dims, 0) < 0) {
+            goto error;
         }
-        ((PyArrayObject_fields *)data_array)->data = new_data;
-        ((PyArrayObject_fields *)data_array)->dimensions[0] = row_count;
     }
 
     /*
