@@ -4,9 +4,6 @@
 #include <numpy/ndarraytypes.h>  /* for NPY_NO_EXPORT */
 
 
-/* For the private exposure of the extobject contextvar to Python */
-extern NPY_NO_EXPORT PyObject *npy_extobj_contextvar;
-
 /*
  * Represent the current ufunc error (and buffer) state.  we are using a
  * capsule for now to store this, but it could make sense to refactor it into
