@@ -43,7 +43,7 @@ PKG_CONFIG = os.environ.get('PKG_CONFIG', 'pkg-config')
 
 
 from run_tests import (
-    get_fake_env
+    get_fake_env, Backend,
 )
 
 from .baseplatformtests import BasePlatformTests
@@ -446,6 +446,24 @@ class LinuxlikeTests(BasePlatformTests):
         libdir = self.installdir + os.path.join(self.prefix, self.libdir)
         self._test_soname_impl(libdir, True)
 
+    @skip_if_not_base_option('b_sanitize')
+    def test_c_link_args_and_env(self):
+        '''
+        Test that the CFLAGS / CXXFLAGS environment variables are
+        included on the linker command line when c_link_args is
+        set but c_args is not.
+        '''
+        if is_cygwin():
+            raise SkipTest('asan not available on Cygwin')
+        if is_openbsd():
+            raise SkipTest('-fsanitize=address is not supported on OpenBSD')
+
+        testdir = os.path.join(self.common_test_dir, '1 trivial')
+        env = {'CFLAGS': '-fsanitize=address'}
+        self.init(testdir, extra_args=['-Dc_link_args="-L/usr/lib"'],
+                  override_envvars=env)
+        self.build()
+
     def test_compiler_check_flags_order(self):
         '''
         Test that compiler check flags override all other flags. This can't be
@@ -590,8 +608,6 @@ class LinuxlikeTests(BasePlatformTests):
         Test that files installed by these tests have the correct permissions.
         Can't be an ordinary test because our installed_files.txt is very basic.
         '''
-        if is_cygwin():
-            self.new_builddir_in_tempdir()
         # Test file modes
         testdir = os.path.join(self.common_test_dir, '12 data')
         self.init(testdir)
@@ -644,8 +660,6 @@ class LinuxlikeTests(BasePlatformTests):
         '''
         Test that files are installed with correct permissions using install_mode.
         '''
-        if is_cygwin():
-            self.new_builddir_in_tempdir()
         testdir = os.path.join(self.common_test_dir, '190 install_mode')
         self.init(testdir)
         self.build()
@@ -684,8 +698,6 @@ class LinuxlikeTests(BasePlatformTests):
         install umask of 022, regardless of the umask at time the worktree
         was checked out or the build was executed.
         '''
-        if is_cygwin():
-            self.new_builddir_in_tempdir()
         # Copy source tree to a temporary directory and change permissions
         # there to simulate a checkout with umask 002.
         orig_testdir = os.path.join(self.unit_test_dir, '26 install umask')
@@ -991,6 +1003,22 @@ class LinuxlikeTests(BasePlatformTests):
             got_rpath = get_rpath(os.path.join(yonder_prefix, 'bin/rpathified'))
             self.assertEqual(got_rpath, yonder_libdir, rpath_format)
 
+    @skip_if_not_base_option('b_sanitize')
+    def test_env_cflags_ldflags(self):
+        if is_cygwin():
+            raise SkipTest('asan not available on Cygwin')
+        if is_openbsd():
+            raise SkipTest('-fsanitize=address is not supported on OpenBSD')
+
+        testdir = os.path.join(self.common_test_dir, '1 trivial')
+        env = {'CFLAGS': '-fsanitize=address', 'LDFLAGS': '-I.'}
+        self.init(testdir, override_envvars=env)
+        self.build()
+        compdb = self.get_compdb()
+        for i in compdb:
+            self.assertIn("-fsanitize=address", i["command"])
+        self.wipe()
+
     @skip_if_not_base_option('b_sanitize')
     def test_pch_with_address_sanitizer(self):
         if is_cygwin():
@@ -1141,6 +1169,42 @@ class LinuxlikeTests(BasePlatformTests):
         pkg_config_path = env.coredata.optstore.get_value('pkg_config_path')
         self.assertEqual(pkg_config_path, [pkg_dir])
 
+    def test_pkgconfig_uninstalled_env_added(self):
+        '''
+        Checks that the meson-uninstalled dir is added to PKG_CONFIG_PATH
+        '''
+        testdir = os.path.join(self.unit_test_dir, '111 pkgconfig duplicate path entries')
+        meson_uninstalled_dir = os.path.join(self.builddir, 'meson-uninstalled')
+
+        env = get_fake_env(testdir, self.builddir, self.prefix)
+
+        newEnv = PkgConfigInterface.setup_env({}, env, MachineChoice.HOST, uninstalled=True)
+
+        pkg_config_path_dirs = newEnv['PKG_CONFIG_PATH'].split(os.pathsep)
+
+        self.assertEqual(len(pkg_config_path_dirs), 1)
+        self.assertEqual(pkg_config_path_dirs[0], meson_uninstalled_dir)
+
+    def test_pkgconfig_uninstalled_env_prepended(self):
+        '''
+        Checks that the meson-uninstalled dir is prepended to PKG_CONFIG_PATH
+        '''
+        testdir = os.path.join(self.unit_test_dir, '111 pkgconfig duplicate path entries')
+        meson_uninstalled_dir = os.path.join(self.builddir, 'meson-uninstalled')
+        external_pkg_config_path_dir = os.path.join('usr', 'local', 'lib', 'pkgconfig')
+
+        env = get_fake_env(testdir, self.builddir, self.prefix)
+
+        env.coredata.set_options({OptionKey('pkg_config_path'): external_pkg_config_path_dir},
+                                 subproject='')
+
+        newEnv = PkgConfigInterface.setup_env({}, env, MachineChoice.HOST, uninstalled=True)
+
+        pkg_config_path_dirs = newEnv['PKG_CONFIG_PATH'].split(os.pathsep)
+
+        self.assertEqual(pkg_config_path_dirs[0], meson_uninstalled_dir)
+        self.assertEqual(pkg_config_path_dirs[1], external_pkg_config_path_dir)
+
     @skipIfNoPkgconfig
     def test_pkgconfig_internal_libraries(self):
         '''
@@ -1829,5 +1893,102 @@ class LinuxlikeTests(BasePlatformTests):
         self.assertIn('build t13-e1: c_LINKER t13-e1.p/main.c.o | libt12-s1.a libt13-s3.a\n', content)
 
     def test_top_options_in_sp(self):
-        testdir = os.path.join(self.unit_test_dir, '123 pkgsubproj')
+        testdir = os.path.join(self.unit_test_dir, '125 pkgsubproj')
         self.init(testdir)
+
+    def test_unreadable_dir_in_declare_dep(self):
+        testdir = os.path.join(self.unit_test_dir, '125 declare_dep var')
+        tmpdir = Path(tempfile.mkdtemp())
+        self.addCleanup(windows_proof_rmtree, tmpdir)
+        declaredepdir = tmpdir / 'test'
+        declaredepdir.mkdir()
+        try:
+            tmpdir.chmod(0o444)
+            self.init(testdir, extra_args=f'-Ddir={declaredepdir}')
+        finally:
+            tmpdir.chmod(0o755)
+
+    def check_has_flag(self, compdb, src, argument):
+        for i in compdb:
+            if src in i['file']:
+                self.assertIn(argument, i['command'])
+                return
+        self.assertTrue(False, f'Source {src} not found in compdb')
+
+    def test_persp_options(self):
+        if self.backend is not Backend.ninja:
+            raise SkipTest(f'{self.backend.name!r} backend can\'t install files')
+
+        testdir = os.path.join(self.unit_test_dir, '122 persp options')
+
+        with self.subTest('init'):
+            self.init(testdir, extra_args='-Doptimization=1')
+            compdb = self.get_compdb()
+            mainsrc = 'toplevel.c'
+            sub1src = 'sub1.c'
+            sub2src = 'sub2.c'
+            self.check_has_flag(compdb, mainsrc, '-O1')
+            self.check_has_flag(compdb, sub1src, '-O1')
+            self.check_has_flag(compdb, sub2src, '-O1')
+
+        # Set subproject option to O2
+        with self.subTest('set subproject option'):
+            self.setconf(['-Dround=2', '-D', 'sub2:optimization=3'])
+            compdb = self.get_compdb()
+            self.check_has_flag(compdb, mainsrc, '-O1')
+            self.check_has_flag(compdb, sub1src, '-O1')
+            self.check_has_flag(compdb, sub2src, '-O3')
+
+        # Change an already set override.
+        with self.subTest('change subproject option'):
+            self.setconf(['-Dround=3', '-D', 'sub2:optimization=2'])
+            compdb = self.get_compdb()
+            self.check_has_flag(compdb, mainsrc, '-O1')
+            self.check_has_flag(compdb, sub1src, '-O1')
+            self.check_has_flag(compdb, sub2src, '-O2')
+
+        # Set top level option to O3
+        with self.subTest('change main project option'):
+            self.setconf(['-Dround=4', '-D:optimization=3'])
+            compdb = self.get_compdb()
+            self.check_has_flag(compdb, mainsrc, '-O3')
+            self.check_has_flag(compdb, sub1src, '-O1')
+            self.check_has_flag(compdb, sub2src, '-O2')
+
+        # Unset subproject
+        with self.subTest('unset subproject option'):
+            self.setconf(['-Dround=5', '-U', 'sub2:optimization'])
+            compdb = self.get_compdb()
+            self.check_has_flag(compdb, mainsrc, '-O3')
+            self.check_has_flag(compdb, sub1src, '-O1')
+            self.check_has_flag(compdb, sub2src, '-O1')
+
+        # Set global value
+        with self.subTest('set global option'):
+            self.setconf(['-Dround=6', '-D', 'optimization=2'])
+            compdb = self.get_compdb()
+            self.check_has_flag(compdb, mainsrc, '-O3')
+            self.check_has_flag(compdb, sub1src, '-O2')
+            self.check_has_flag(compdb, sub2src, '-O2')
+
+    def test_sanitizers(self):
+        testdir = os.path.join(self.unit_test_dir, '127 sanitizers')
+
+        with self.subTest('no b_sanitize value'):
+            try:
+                out = self.init(testdir)
+                self.assertRegex(out, 'value *: *none')
+            finally:
+                self.wipe()
+
+        for value, expected in { '': 'none',
+                                 'none': 'none',
+                                 'address': 'address',
+                                 'undefined,address': 'address,undefined',
+                                 'address,undefined': 'address,undefined' }.items():
+            with self.subTest('b_sanitize=' + value):
+                try:
+                    out = self.init(testdir, extra_args=['-Db_sanitize=' + value])
+                    self.assertRegex(out, 'value *: *' + expected)
+                finally:
+                    self.wipe()
